#! /usr/bin/env python2
# -*- coding: utf-8 -*-
"""
Replacement (unofficial) `setup.py` for the `hr_attendance` module.
Automatically generated by `openerpdist`. See http://noteed.com/openerpdist/.
"""

import setuptools

setuptools.setup(
    name = "openerp-hr-attendance",
    version = "7.0.355",
    description = "Attendances",
    long_description = 
"""

This module aims to manage employee's attendances.
==================================================

Keeps account of the attendances of the employees on the basis of the
actions(Sign in/Sign out) performed by them.
       
""",
    url = "",
    author = "OpenERP SA",
    author_email = "TODO",
    classifiers = [
        "Development Status :: 5 - Production/Stable",
        "Environment :: Plugins",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: GNU Affero General Public License v3",
        "Natural Language :: English",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: Implementation :: CPython",
    ],
    license = "AGPL-3",
    package_dir = {
        'openerp.addons.hr_attendance': ".",
    },
    packages = ["openerp.addons.hr_attendance","openerp.addons.hr_attendance.report","openerp.addons.hr_attendance.wizard"],
    package_data = {
        'openerp.addons.hr_attendance': ["i18n/*.po*","res_config_view.xml","hr_attendance_report.xml","hr_attendance_demo.xml","hr_attendance_view.xml","images/hr_attendances.jpeg","static/src/xml/attendance.xml","static/src/js/attendance.js","static/src/img/emp-in-disable32.png","static/src/img/emp-out32.png","static/src/img/emp-out-disable32.png","static/src/img/emp-in32.png","i18n/id.po","i18n/hr.po","i18n/da.po","i18n/sl.po","i18n/es_MX.po","i18n/ru.po","i18n/zh_TW.po","i18n/en_GB.po","i18n/cs.po","i18n/sq.po","i18n/fi.po","i18n/pt_BR.po","i18n/ko.po","i18n/bg.po","i18n/es_VE.po","i18n/tlh.po","i18n/es_PY.po","i18n/ja.po","i18n/ro.po","i18n/es_AR.po","i18n/sr@latin.po","i18n/es.po","i18n/mn.po","i18n/es_CL.po","i18n/it.po","i18n/nl.po","i18n/sv.po","i18n/es_EC.po","i18n/uk.po","i18n/bs.po","i18n/tr.po","i18n/de.po","i18n/et.po","i18n/sr.po","i18n/lt.po","i18n/hu.po","i18n/vi.po","i18n/el.po","i18n/gl.po","i18n/lv.po","i18n/mk.po","i18n/ca.po","i18n/fr.po","i18n/zh_CN.po","i18n/pl.po","i18n/he.po","i18n/th.po","i18n/nl_BE.po","i18n/nb.po","i18n/ar.po","i18n/pt.po","i18n/es_CR.po","test/attendance_process.yml","test/hr_attendance_report.yml","security/ir.model.access.csv","security/ir_rule.xml","report/timesheet.xsl","report/bymonth.xsl","report/hr_custom_rml.xsl","report/attendance_errors.rml","report/attendance_errors.sxw","report/hr_custom_default.xsl","wizard/hr_attendance_error_view.xml","wizard/hr_attendance_byweek_view.xml","wizard/hr_attendance_bymonth_view.xml","security/ir_rule.xml","security/ir.model.access.csv","hr_attendance_view.xml","hr_attendance_report.xml","wizard/hr_attendance_bymonth_view.xml","wizard/hr_attendance_byweek_view.xml","wizard/hr_attendance_error_view.xml","res_config_view.xml","hr_attendance_demo.xml","static/src/xml/attendance.xml","static/src/css/slider.css","static/src/js/attendance.js"],
    },
    install_requires = ["openerp-hr"],
    tests_require = ["unittest2"],
)
